@@ -22,7 +22,7 @@ Sampler <- R6::R6Class(
 #' Samplers can be used with [dataloader()] when creating batches from a torch
 #' [dataset()].
 #' 
-#' A sampler must implement the `.iter` and `.lenght()` methods.
+#' A sampler must implement the `.iter` and `.length()` methods.
 #' - `initialize` takes in a `data_source`. In general this is a [dataset()].
 #' - `.iter` returns a function that returns a dataset index everytime it's called.
 #' - `.length` returns the maximum number of samples that can be retrieved from
@@ -59,10 +59,12 @@ SequentialSampler <- sampler(
   initialize = function(data_source) {
     self$data_source <- data_source
   },
-  .iter = function() {
-    i <- 0
+  .iter_batch = function(batch_size) {
     n <- length(self$data_source)
-    coro::as_iterator(seq_len(n))
+    as_batch_iterator(seq_len(n), batch_size)
+  },
+  .iter = function() {
+    self$.iter_batch(1L)
   },
   .length = function() {
     length(self$data_source)
@@ -77,7 +79,7 @@ RandomSampler <- sampler(
     self$.num_samples <- num_samples
     self$generator <- generator
   },
-  .iter = function() {
+  .iter_batch = function(batch_size) {
     n <- length(self$data_source)
     
     if (self$replacement) {
@@ -89,7 +91,10 @@ RandomSampler <- sampler(
       rand_tensor <- torch_randperm(n)$add(1L, 1L) # , generator = self$generator)
     }
     rand_tensor <- as_array(rand_tensor$to(dtype = torch_int()))
-    as_iterator(rand_tensor)
+    as_batch_iterator(rand_tensor, batch_size)
+  },
+  .iter = function() {
+    self$.iter_batch(1L)
   },
   .length = function() {
     self$num_samples
@@ -112,22 +117,38 @@ BatchSampler <- sampler(
     self$batch_size <- batch_size
     self$drop_last <- drop_last
   },
-  .iter = function() {
-    coro::generator(function() {
+  .iter_batch_sampler = function() {
+    samp <- self$sampler$.iter_batch(self$batch_size)
+    function() {
+      batch <- samp()
+      if (coro::is_exhausted(batch)) return(batch)
+      if (length(batch) == self$batch_size) return(batch)
+      if (length(batch) > 0 && !self$drop_last) return(batch)
+      coro::exhausted()
+    }
+  },
+  .iter_sampler = function() {
+    samp <- self$sampler$.iter()
+    function() {
       batch <- list()
-      
-      for (idx in self$sampler) {
-        batch[[length(batch) + 1]] <- idx
-        if (length(batch) == self$batch_size) {
-          yield(batch)
-          batch <- list()
-        }
+      repeat {
+        id <- samp()
+        if (coro::is_exhausted(id)) break
+        batch[[length(batch) + 1]] <- id
+        if (length(batch) == self$batch_size) return(batch)
       }
-      
       if (length(batch) > 0 && !self$drop_last) {
-        yield(batch)
+        return(batch)
       }
-    })()
+      coro::exhausted()
+    }
+  },
+  .iter = function() {
+    if (!is.null(self$sampler$.iter_batch)) {
+      self$.iter_batch_sampler()
+    } else {
+      self$.iter_sampler()
+    }
   },
   .length = function() {
     if (self$drop_last) {
@@ -145,3 +166,30 @@ as_iterator.utils_sampler <- function(x) {
     it()
   }
 }
+
+as_iterator_f <- function(x) {
+  n <- length(x)
+  i <- 0L
+  function() {
+    if (i == n) {
+      return(coro::exhausted())
+    }
+    i <<- i + 1L
+    x[i]
+  }
+}
+
+as_batch_iterator <- function(x, batch_size) {
+  n <- length(x)
+  i <- 1L
+  batch_size <- as.integer(batch_size)
+  function() {
+    if (i > n) {
+      return(coro::exhausted())
+    }
+    end <- if ((i + batch_size - 1) > n) n else (i + batch_size - 1)
+    out <- x[seq(i,end)]
+    i <<- i + batch_size
+    out
+  }
+}
