@@ -477,7 +477,7 @@ test_that("modules method", {
   )
 })
 
-test_that("lenght for sequential modules", {
+test_that("length for sequential modules", {
   m <- nn_sequential(
     nn_conv2d(10, 10, c(5, 5)),
     nn_conv2d(10, 10, c(5, 5))
@@ -629,4 +629,33 @@ test_that("classes are inherited correctly", {
 test_that("empty initializer", {
   model <- nn_module(forward = function(input) input)
   expect_equal_to_r(model()(torch_tensor(1)), 1)
+})
+
+test_that("can load state dict of a corrupt module", {
+  local_edition(3)
+  
+  model <- nn_linear(10, 10)
+  tmp <- tempfile(fileext = "rds")
+  saveRDS(model, tmp)
+  rm(model); gc();
+  model <- readRDS(tmp)
+  
+  err <- try({model$parameters$weight$abs()}, silent = TRUE)
+  expect_true(inherits(err, "try-error"))
+  
+  expect_error(regexp = NA, {
+    model$load_state_dict(list(weight = torch_randn(10, 10), bias = torch_randn(10)))  
+  })
+
+  expect_tensor_shape(model(torch_randn(10, 10)), c(10, 10))
+})
+
+test_that("make sure state_dict() is detached", {
+  model <- nn_linear(10, 10)
+  model$bias$requires_grad_(FALSE) 
+  state_dict <- model$state_dict()
+  
+  expect_true(state_dict$weight$requires_grad)
+  # we should keep the save value of requires grad bt in a detached graph
+  expect_false(state_dict$bias$requires_grad)
 })
\ No newline at end of file
